=head1 NAME

Local::Cluster - Stub of Cluster modules.

=cut
package Local::Cluster;

use warnings;
use strict;

=head1 VERSION

Version 0.02

=cut

our $VERSION = '0.02';

=head1 MODULES

=head2 Local::Cluster::CLI::Cache

CLI for cluster cache

=head2 Local::Cluster::CLI::Range

CLI for Cluster Range - expand/digest/count

=head2 Local::Cluster::CLI::Server

CLI for cluster server

=head2 Local::Cluster::Cache 

Caching server. Implements Cluster::Interface.

=head2 Local::Cluster::Client 

Cluster client

=head2 Local::Cluster::Config 

Cluster configuration methods

=head2 Local::Cluster::EZDB

Extends Local::EZDB

=head2 Local::Cluster::Interface

Extends TCPServer::Interface.

=head2 Local::Cluster::Range

Extends Range::String.

=head2 Local::Cluster::Server 

Cluster server. Implements Cluster::Interface.

=head1 AUTHOR

Kan Liu

=head1 COPYRIGHT and LICENSE

Copyright (c) 2010. Kan Liu

This program is free software; you may redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;

__END__
